
/*
 * kvadap.h -- definitions for the char module
 *
 *********/

#include <linux/ioctl.h>

/* version dependencies have been confined to a separate file */

#define VERSION_CODE(vers,rel,seq) ( ((vers)<<16) | ((rel)<<8) | (seq) )
#include "sysdep.h"

/*
 * Serial port parameters
 */
 
#define SERIAL_IRQ  4
#define SERIAL_PORT 0x3f8
#define SERIAL_NUM  0

/*
 * Macros to help debugging
 */

#undef PDEBUG             /* undef it, just in case */
#ifdef KVADAP_DEBUG
#  ifdef __KERNEL__
     /* This one if debugging is on, and kernel space */
#    define PDEBUG(fmt, args...) printk( KERN_DEBUG "kvadap: " fmt, ## args)
#  else
     /* This one for user space */
#    define PDEBUG(fmt, args...) fprintf(stderr, fmt, ## args)
#  endif
#else
#  define PDEBUG(fmt, args...) /* not debugging: nothing */
#endif

#undef PDEBUGG
#define PDEBUGG(fmt, args...) /* nothing: it's a placeholder */

#ifndef KVADAP_MAJOR
#define KVADAP_MAJOR 0   /* dynamic major by default */
#endif

#define DSP_MAX_CHARS 64
#define PRT_MAX_CHARS 64
#define KEY_MAX_CHARS 32

#define PRT_BUSY_FLAG 	0x0001
#define REL_FLAG	  	0x0002
#define MAI_FLAG		0x0004
#define CTRL_FLAG		0x0008
#define SPEC_FLAG		0x0010

typedef struct Kvadap_Dev {
	int type;
	int activity;
	int flags;
	struct wait_queue *dspq,*prtq,*keyq;
	char dspbuf[DSP_MAX_CHARS];
	int dspin,dspout;
	char keybuf[KEY_MAX_CHARS];
	int keyin,keyout;
} Kvadap_Dev;

typedef struct Kvadap_Prt_Dev {
	int type;
	int in,out;
	char buf[PRT_MAX_CHARS];
} Kvadap_Prt_Dev;


extern struct file_operations kvadap_fops;        /* simplest: global */

extern int kvadap_major;     /* main.c */

read_write_t kvadap_read (struct inode *inode, struct file *filp,
                char *buf, count_t count);
read_write_t kvadap_write (struct inode *inode, struct file *filp,
                const char *buf, count_t count);
int kvadap_lseek (struct inode *inode, struct file *filp,
                 off_t off, int whence);
int kvadap_ioctl (struct inode *inode, struct file *filp,
                 unsigned int cmd, unsigned long arg);


#ifdef KVADAP_DEBUG
#  if LINUX_VERSION_CODE > VERSION_CODE(1,99,3) /* 1.99.4 exported the needed symbols */
#    define KVADAP_USE_PROC
#  endif
#endif

#ifndef min
#  define min(a,b) ((a)<(b) ? (a) : (b))
#endif

/*
 * Ioctl definitions
 */

/* Use 'k' as magic number */
#define KVADAP_IOC_MAGIC  'k'

#define KVADAP_IOCRESET    _IO(KVADAP_IOC_MAGIC, 0)
#define KVADAP_IOCSADDR    _IO(KVADAP_IOC_MAGIC, 1)
#define KVADAP_IOCGADDR    _IO(KVADAP_IOC_MAGIC, 2)
#define KVADAP_IOCGPCNT	   _IO(KVADAP_IOC_MAGIC, 3)

#define KVADAP_IOC_MAXNR 3
